@@ -1,4 +1,5 @@
 test_that("comparing two codelists", {
+  skip_on_cran()
   backends <- c("database")
 
   for (i in seq_along(backends)) {
@@ -20,12 +21,20 @@ test_that("comparing two codelists", {
       includeDescendants = TRUE
     )
 
+    # candidate_class codelist
     codesCompared <- compareCodelists(
       codelist1 = codes1,
       codelist2 = codes2
     )
 
-    # tests
+    # compare codelist with details
+    codesCompared2 <- compareCodelists(
+      codelist1 = omopgenerics::newCodelistWithDetails(list("codelist1" = codes1)),
+      codelist2 = omopgenerics::newCodelistWithDetails(list("codelist2" = codes2))
+    )
+
+    expect_identical(codesCompared, codesCompared2)
+
     expect_true(all(c(
       "concept_id",
       "concept_name",
@@ -36,12 +45,12 @@ test_that("comparing two codelists", {
     expect_true(codesCompared |>
       dplyr::filter(concept_id == 3) |>
       dplyr::select(codelist) |>
-      dplyr::pull() == "Only codelist 1")
+      dplyr::pull() == "Only in codelist codelist1")
 
     expect_true(codesCompared |>
       dplyr::filter(concept_id == 5) |>
       dplyr::select(codelist) |>
-      dplyr::pull() == "Only codelist 1")
+      dplyr::pull() == "Only in codelist codelist1")
 
     expect_true(codesCompared |>
       dplyr::filter(concept_id == 4) |>
@@ -51,7 +60,7 @@ test_that("comparing two codelists", {
     expect_true(codesCompared |>
       dplyr::filter(concept_id == 2) |>
       dplyr::select(codelist) |>
-      dplyr::pull() == "Only codelist 2")
+      dplyr::pull() == "Only in codelist codelist2")
 
     # expected errors
     expect_error(compareCodelists(
@@ -63,29 +72,27 @@ test_that("comparing two codelists", {
       codelist2 = codes2
     ))
 
-
-
     # compare codelist
     codesCompared <- compareCodelists(
-    omopgenerics::newCodelist(list(a = c(1L, 2L))),
-    omopgenerics::newCodelist(list(b = c(2L, 3L)))
+      omopgenerics::newCodelist(list("a" = c(1L, 2L), "c" = c(4L))),
+      omopgenerics::newCodelist(list("b" = c(2L, 3L), "d" = c(4L)))
     )
 
-    expect_true(codesCompared |>
+    expect_true(inherits(codesCompared, "list"))
+    expect_equal(names(codesCompared), c("a_b", "a_d", "c_b", "c_d"))
+    expect_true(codesCompared$a_b |>
                   dplyr::filter(concept_id == 1) |>
                   dplyr::select("codelist") |>
-                  dplyr::pull() == "Only codelist 1")
+                  dplyr::pull() == "Only in codelist a")
 
-    expect_true(codesCompared |>
-                  dplyr::filter(concept_id == 2) |>
+    expect_true(codesCompared$c_d |>
                   dplyr::select("codelist") |>
                   dplyr::pull() == "Both")
 
-    expect_true(codesCompared |>
+    expect_true(codesCompared$a_b |>
                   dplyr::filter(concept_id == 3) |>
                   dplyr::select("codelist") |>
-                  dplyr::pull() == "Only codelist 2")
-
+                  dplyr::pull() == "Only in codelist b")
 
     if (backends[[i]] == "database") {
       CDMConnector::cdmDisconnect(cdm)
@@ -117,11 +124,12 @@ test_that("comparing two codelists- same codes found different ways", {
     )
 
     codesCompared <- compareCodelists(
-      codelist1 = codes1,
-      codelist2 = codes2
+      codelist1 = omopgenerics::newCodelistWithDetails(list("codes1" = codes1)),
+      codelist2 = omopgenerics::newCodelistWithDetails(list("codes2" = codes2))
     )
 
     # tests
+    expect_true(inherits(codesCompared, "tbl"))
     expect_true(nrow(codesCompared) == 4)
 
     expect_true(codesCompared |>
@@ -142,7 +150,7 @@ test_that("comparing two codelists- same codes found different ways", {
     expect_true(codesCompared |>
       dplyr::filter(concept_id == 2) |>
       dplyr::select(codelist) |>
-      dplyr::pull() == "Only codelist 2")
+      dplyr::pull() == "Only in codelist codes2")
 
     if (backends[[i]] == "database") {
       CDMConnector::cdmDisconnect(cdm)
