@@ -6,6 +6,17 @@ test_that("tests with mock db", {
     # mock db
     cdm <- mockVocabRef(backends[[i]])
 
+    # check tidyWords
+    expect_message(tidyWords(c("café")))
+    expect_message(x <- tidyWords(c("/hip")))
+    expect_identical(x, "hip")
+    expect_message(x <- tidyWords(c("/hép/")))
+    expect_identical(x, "hp")
+    expect_message(x <- tidyWords(c("?")))
+    expect_identical(x,as.character())
+    expect_message(x <- tidyWords(c("?", "hello")))
+    expect_identical(x,"hello")
+
     # tests
     # test keywords search - exact
     codes <- getCandidateCodes(
@@ -15,7 +26,7 @@ test_that("tests with mock db", {
       includeDescendants = FALSE
     )
     expect_true((nrow(codes) == 1 &
-      codes$concept_name[1] == "Musculoskeletal disorder"))
+                   codes$concept_name[1] == "Musculoskeletal disorder"))
     # variable names
     expect_true(all(c(
       "concept_id", "concept_name",
@@ -34,13 +45,58 @@ test_that("tests with mock db", {
     )
     expect_true(nrow(codes) == 2)
     expect_true("Osteoarthritis of knee" %in%
-      (codes |>
-      dplyr::pull("concept_name")))
+                  (codes |>
+                     dplyr::pull("concept_name")))
     expect_true("Osteoarthritis of hip" %in%
                   (codes |>
                      dplyr::pull("concept_name")))
 
+    # exact matches
+    cdm$concept <- cdm$concept |>
+      dplyr::union_all(
+        cdm$concept |>
+          dplyr::filter(concept_name == "Knee osteoarthritis") |>
+          dplyr::mutate("standard_concept" = "S",
+                        "concept_id" = 27L)
+      )
+    codes <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "knee osteo",
+      domains = "Condition",
+      includeDescendants = FALSE
+    )
+    codes1 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "/knee osteo/",
+      domains = "Condition",
+      includeDescendants = FALSE
+    )
+    codes2 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "/\bknee osteo/\b",
+      domains = "Condition",
+      includeDescendants = FALSE
+    )
+    codes3 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "/\bknee osteoarthritis/\b",
+      domains = "Condition",
+      includeDescendants = FALSE
+    )
+    codes4 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "knee osteoarthritis",
+      domains = "Condition",
+      includeDescendants = FALSE
+    )
+    expect_identical(codes$concept_id, c(4L, 27L))
+    expect_identical(codes1$concept_id, c(27L))
+    expect_identical(codes2$concept_id, integer(0))
+    expect_identical(codes3$concept_id, c(27L))
+    expect_identical(codes4$concept_id, codes$concept_id)
+
     # test include descendants
+    cdm <- mockVocabRef()
     codes <- getCandidateCodes(
       cdm = cdm,
       keywords = "Musculoskeletal disorder",
@@ -48,8 +104,8 @@ test_that("tests with mock db", {
       includeDescendants = TRUE
     )
     expect_true((nrow(codes) == 5 &
-      all(codes$concept_id %in% c(1:5)) &
-      all(!codes$concept_id %in% c(6, 7))))
+                   all(codes$concept_id %in% c(1:5)) &
+                   all(!codes$concept_id %in% c(6, 7))))
 
     # test include ancestor
     codes <- getCandidateCodes(
@@ -79,9 +135,8 @@ test_that("tests with mock db", {
       includeDescendants = TRUE
     )
     expect_true((nrow(codes) == 5 &
-      all(codes$concept_id %in% c(3, 4, 5, 8, 17)) &
-      all(!codes$concept_id %in% c(1, 2, 7))))
-
+                   all(codes$concept_id %in% c(3, 4, 5, 8, 17)) &
+                   all(!codes$concept_id %in% c(1, 2, 7))))
 
     # test searchInSynonyms
     codes <- getCandidateCodes(
@@ -117,6 +172,88 @@ test_that("tests with mock db", {
     )
     expect_true(all(codes$concept_name != "Osteoarthritis of hip"))
 
+    # test exclusion + partial match
+    codes1 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "arthritis",
+      exclude = NULL,
+      domains = "Condition",
+      standardConcept = c("Standard", "Non-standard")
+    )
+
+    expect_message(codes2 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "arthritis",
+      exclude = c("hip of", "/Knee Osteoarthritis"),
+      domains = "Condition",
+      standardConcept = c("Standard", "Non-standard")
+    ))
+    expect_equal(
+      {attr(codes1, "search_strategy") <- NULL; codes1 |> dplyr::filter(.data$concept_id %in% c(3L, 17L))},
+      {attr(codes2, "search_strategy") <- NULL; codes2}
+    )
+
+    codes3 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "arthritis",
+      exclude = c("hip of", "/Knee Osteoarthritis/"),
+      domains = "Condition",
+      standardConcept = c("Standard", "Non-standard")
+    )
+
+    codes4 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "arthritis",
+      exclude = c("hip of", "/ee Osteoarthritis/"),
+      domains = "Condition",
+      standardConcept = c("Standard", "Non-standard")
+    )
+    expect_equal(
+      {attr(codes1, "search_strategy") <- NULL; codes1 |> dplyr::filter(!.data$concept_id %in% c(5L, 8L))},
+      {attr(codes3, "search_strategy") <- NULL; codes3}
+    )
+    expect_equal(
+      {attr(codes3, "search_strategy") <- NULL; codes3},
+      {attr(codes4, "search_strategy") <- NULL; codes4}
+    )
+
+    codes5 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "arthritis",
+      exclude = c("hip of", "/\bee Osteoarthritis/\b"),
+      domains = "Condition",
+      standardConcept = c("Standard", "Non-standard")
+    )
+    expect_equal(
+      {attr(codes1, "search_strategy") <- NULL; codes1 |> dplyr::filter(!.data$concept_id %in% c(5L))},
+      {attr(codes5, "search_strategy") <- NULL; codes5}
+    )
+
+    codes6 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "arthritis",
+      exclude = c("hip of", "/\bknee Osteoarthritis/\b"),
+      domains = "Condition",
+      standardConcept = c("Standard", "Non-standard")
+    )
+    expect_equal(
+      {attr(codes4, "search_strategy") <- NULL; codes4},
+      {attr(codes6, "search_strategy") <- NULL; codes6}
+    )
+
+    # test exclusion + symbols (to ignore)
+    expect_message(codes7 <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "arthritis",
+      exclude = c("?"),
+      domains = "Condition",
+      standardConcept = c("Standard", "Non-standard")
+    ))
+    expect_equal(
+      {attr(codes1, "search_strategy") <- NULL; codes1},
+      {attr(codes7, "search_strategy") <- NULL; codes7}
+    )
+
     # test non-standard
     codes <- getCandidateCodes(
       cdm = cdm,
@@ -139,8 +276,8 @@ test_that("tests with mock db", {
     # all options
     codes <- getCandidateCodes(
       cdm = cdm,
-      keywords = "arthritis",
-      domains = "Condition",
+      keywords = c("arthritis", "knee"),
+      domains = c("Condition", "observation"),
       standardConcept = "Standard",
       searchInSynonyms = TRUE,
       searchNonStandard = TRUE,
@@ -150,7 +287,6 @@ test_that("tests with mock db", {
     )
     expect_true(nrow(codes) >= 1)
 
-
     # test search in drug
     codes <- getCandidateCodes(
       cdm = cdm,
@@ -185,7 +321,7 @@ test_that("tests with mock db", {
 
     ## Edge cases
     # check empty candidate set
-   codes <- getCandidateCodes(
+    codes <- getCandidateCodes(
       cdm = cdm,
       keywords = "asthmaX",
       domains = "Condition"
@@ -201,7 +337,7 @@ test_that("tests with mock db", {
     )
     expect_true("1" %in% codes$concept_id)
 
-   codes <- getCandidateCodes(
+    codes <- getCandidateCodes(
       cdm = cdm,
       keywords = "XXXXX",
       standardConcept = c("Standard"),
@@ -235,7 +371,7 @@ test_that("tests with mock db", {
     ))
 
     # domain that doesn´t exist
-    expect_error(getCandidateCodes(
+    expect_warning(getCandidateCodes(
       cdm = cdm,
       keywords = "arthritis",
       domains = c("Condition", "Some other table")
@@ -270,6 +406,7 @@ test_that("tests with mock db", {
 })
 
 test_that("tests with mock db - multiple domains", {
+  skip_on_cran()
   backends <- c("database",
                 "data_frame")
 
@@ -286,8 +423,8 @@ test_that("tests with mock db - multiple domains", {
       includeDescendants = FALSE
     )
     expect_true((nrow(codes) == 4 &
-      all(codes$concept_id %in% c(3:5, 9)) &
-      all(!codes$concept_id %in% c(1, 2, 6, 7, 8))))
+                   all(codes$concept_id %in% c(3:5, 9)) &
+                   all(!codes$concept_id %in% c(1, 2, 6, 7, 8))))
 
     codes <- getCandidateCodes(
       cdm = cdm,
@@ -297,7 +434,7 @@ test_that("tests with mock db - multiple domains", {
     )
     expect_true(all(
       nrow(codes) == 3 &
-      c(4,5,9) %in% codes$concept_id))
+        c(4,5,9) %in% codes$concept_id))
 
     if (backends[[i]] == "database") {
       CDMConnector::cdmDisconnect(cdm)
@@ -317,34 +454,38 @@ test_that("tests with eunomia", {
     writeSchema = "main"
   )
 
- codes <- getCandidateCodes(cdm=cdm,
-                  keywords= "sinusitis",
-                  domains = c("Condition", "observation"),
-                  searchInSynonyms = TRUE,
-                  searchNonStandard = TRUE,
-                  includeAncestor = TRUE)
+  codes <- getCandidateCodes(cdm=cdm,
+                             keywords= "sinusitis",
+                             domains = c("Condition", "observation"),
+                             searchInSynonyms = TRUE,
+                             searchNonStandard = TRUE,
+                             includeAncestor = TRUE)
 
- expect_true(sum(is.na(codes$concept_name)) == 0)
+  expect_true(sum(is.na(codes$concept_name)) == 0)
 
- expect_equal(codes |>
-   dplyr::pull("concept_id"),
- unique(codes |>
-   dplyr::pull("concept_id")))
+  expect_equal(codes |>
+                 dplyr::pull("concept_id"),
+               unique(codes |>
+                        dplyr::pull("concept_id")))
 
- codes1 <- getCandidateCodes(cdm=cdm,
-                            keywords= c("Protein","disease"),
-                            domains = NULL,
-                            searchInSynonyms = TRUE,
-                            searchNonStandard = TRUE,
-                            includeAncestor = TRUE)
- codes1 <- codes1 |> dplyr::arrange(concept_id)
- codes2 <- getCandidateCodes(cdm=cdm,
-                            keywords= c("Protein","disease"),
-                            domains = c("Condition", "Drug", "Procedure", "Device", "Observation", "Measurement"),
-                            searchInSynonyms = TRUE,
-                            searchNonStandard = TRUE,
-                            includeAncestor = TRUE)
- codes2 <- codes2 |> dplyr::arrange(concept_id)
- expect_identical(codes1, codes2)
+  codes1 <- getCandidateCodes(cdm=cdm,
+                              keywords= c("Protein","disease"),
+                              domains = NULL,
+                              searchInSynonyms = TRUE,
+                              searchNonStandard = TRUE,
+                              includeAncestor = TRUE)
+  codes1 <- codes1 |> dplyr::arrange(concept_id)
+  expect_warning(codes2 <- getCandidateCodes(cdm=cdm,
+                                             keywords= c("Protein","disease"),
+                                             domains = c("Condition", "Drug", "Procedure", "Device", "Observation", "Measurement"),
+                                             searchInSynonyms = TRUE,
+                                             searchNonStandard = TRUE,
+                                             includeAncestor = TRUE))
+  codes2 <- codes2 |> dplyr::arrange(concept_id)
+
+  expect_equal(
+    {attr(codes1, "search_strategy") <- NULL; codes1},
+    {attr(codes2, "search_strategy") <- NULL; codes2}
+  )
 
 })
